## 0.2.0

* SDO server: segmented, expetited and block transfer working for upload and download
* default of 127 SDO servers per node

## 0.1.1

* adding long description in setup.py

## 0.1.0

* initial version
